all.Carss<-function(){
     cat("\n")
     note_for_CBZss_input()
     cat("\n")
     note_for_close_window()
     CBZSSpar<-data.frame(parameter=c("TBW (kg)","PB","VPA","PHT","E","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))
     CBZSSpar<-edit(CBZSSpar)
##     CBZSSpar<-ycheck(CBZSSpar)
     cat("\n")
     Car.ss(CBZSSpar[9,2],CBZSSpar[7,2],CBZSSpar[8,2],CBZSSpar[6,2],CBZSSpar[1,2],CBZSSpar[2,2],CBZSSpar[3,2],CBZSSpar[4,2],CBZSSpar[5,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_CBZss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-pocpr(1.2,CBZSSpar[6,2],CBZSSpar[7,2],CBZSSpar[8,2])               # calculate predicted steady-state measured concentration of Carbamazepine (equation of oral concentration)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-pocpr(1.2,CBZSSpar[6,2],CBZSSpar[7,2],CBZSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)     
     cat("\n")   
     Car.more()
}